module RotationalTransform
using VMEC
using MPI

function computeTarget(args::Dict{Symbol,Any},vmec::Vmec{T}) where {T <: AbstractFloat}
  return vmec.iota(args[:surfaceLabel])
end

function computeTarget(args::Dict{Symbol,Any},vmecSurface::VmecSurface{T}) where {T <: AbstractFloat}
  if args[:surfaceLabel] != vmecSurface.s
    throw(error("Input surface label and VmecSurface do not match"))
  end
  return vmecSurface.iota[1]
end

function computeTarget(args::Dict{Symbol,Any},vmecSurface::VmecSurface{T},comm::MPI.Comm) where {T <: AbstractFloat}
  return vmecSurface.iota[1]
end

end

module AspectRatio
using VMEC
using MPI

function computeTarget(args::Dict{Symbol,Any},vmecSurface::VmecSurface{T},comm::MPI.Comm) where {T <: AbstractFloat}
  return vmecSurface.aspect
end

end

module MagneticWell
using VMEC
using MPI

function computeTarget(args::Dict{Symbol,Any},
                       vmecSurface::VmecSurface{T},
                       comm::MPI.Comm) where {T <: AbstractFloat}
  return -vmecSurface.vp[2]*vmecSurface.signgs
end

end
