module VMEC
using Libdl
using VMEC_jll
using MPI
using LinearAlgebra
using StaticArrays
using StructArrays
using CoordinateTransformations
using Interpolations
using Roots
using Polyester

using PlasmaEquilibriumToolkit

include("Exports.jl")
include("VmecTypes.jl")
include("NamelistInput.jl")
include("FortranInterface.jl")
include("NetCDFUtils.jl")
include("FourierTransformFunctions.jl")
include("VmecUtils.jl")
include("Coordinates.jl")
include("Boozer.jl")
include("Output.jl")

include("OptimizationTargets.jl")

const libvmec_ref = Ref{String}("")

function __init__()
    if occursin("Intel",Sys.cpu_info()[1].model)
        try
            dlopen(libvmec_mkl)
            dlclose(libvmec_mkl)
            libvmec_ref[] = libvmec_mkl
        catch
            @debug "Optimized Intel MKL libraries for Intel chipset not found, falling back to OpenBLAS/SCALAPACK for VMEC"
            libvmec_ref[] = libvmec_openblas
        end
    else
        libvmec_ref[] = libvmec_openblas
    end
end
end
